/**
 * @Author Bharath A Reddy
 */
import java.util.StringTokenizer;
import java.util.Properties;
import java.util.Enumeration;
import java.util.Vector;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;

/**
 * This Program loads a specified property file which is be located
 * in the classpath.
 */
public class PropertyFileReader{
	private Properties data;
	private String file;

	/**
	 * Default Constructor
	 */
	public PropertyFileReader(){
	}

	/**
	 * Constructor which loads the properties file
	 *
	 * @param file the .properties file that should be loaded
 	 * @exception java.io.FileNotFoundException Thrown when either the file is not found.
 	 * @exception java.io.IOException Thrown when unable to read the file
	 */
	public PropertyFileReader(String file) throws FileNotFoundException,IOException{
		setPropertyFile(file);
	}

	// actual method which tests the availability of the specified file in the
	// classpath and loads it.
	private void loadPropertiesFile() throws FileNotFoundException,IOException{
		String paths[] = getPaths();
		FileInputStream fis = null;
		for( int i=0 ; i < paths.length ; i++ ){

			String filePath = trimFileSeparator( paths[i] , System.getProperty("file.separator") ) + file;
			File checkFile = new File(filePath);
			if( checkFile.exists() ){
				fis = new FileInputStream(checkFile);
				break;
			}
		}
		if( fis == null ){
			throw new FileNotFoundException("File Not Found :"+file);
		}else{
			data.load(fis);
			fis.close();
		}
	}

	/**
	 * After loading the properties file either by using the constructor or
	 * setPropertyFile this method should be called to get the actual Properties
	 * Object which contains the properties.
	 *
	 * @return java.util.Properties Object which encapsulates the contents of the
	 *         contents of the Properties file loaded.
	 */
	public Properties getProperties(){
		return data;
	}

	/**
	 * This method loads the properties file specified
	 *
	 * @param file the .properties file that should be loaded
 	 * @exception java.io.FileNotFoundException Thrown when either the file is not found.
 	 * @exception java.io.IOException Thrown when unable to read the file
	 */
	public void setPropertyFile(String file) throws FileNotFoundException,IOException{
		data = new Properties();
		this.file = file;
		loadPropertiesFile();
	}

	/**
	 * Constructor which loads the properties file
	 *
	 * @return the Property file.
	 */
	public String getPropertyFile(){
		return file;
	}

	// trims the trailing file path separator eg: '\' for Windows
	private String trimFileSeparator(String path,String fileSeparator){
		if( !path.endsWith(fileSeparator) ){
			return path + fileSeparator;
		}else{
			return path;
		}
	}

	// returns the paths specified in the classpath
	private String[] getPaths(){
		String classpath = System.getProperty("java.class.path");
		StringTokenizer stk = new StringTokenizer(classpath,System.getProperty("path.separator"));
		java.util.Vector temp = new java.util.Vector(10,1);
		while( stk.hasMoreTokens() ){
			String st = stk.nextToken();
			if( !st.trim().equals("") ){
				temp.addElement(st);
			}
		}
		String array[] = new String[temp.size()];
		for(int i=0 ; i < temp.size() ; i++ ){
			array[i] = (String)temp.elementAt(i);
		}
		return array;
	}

	public static void main(String[] args) throws Exception{
		PropertyFileReader prop = new PropertyFileReader("awt.properties");
		//prop.getProperties().list(System.out);
	}
}